==> arf-4.1.1-en-download.zip: arf-4.1.1-en/webhelp/arf-webhelp/wca/navig/contents_wca.js <==
//
//	FindinSite-CD-JS-HelpIndex database entirenetworkadministration
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entirenetworkadministration = {
    baseurls: ["../"],
    varname: "entirenetworkadministration",
    tree: [
        { url: "overview.htm", title: "Entire Net-Work Administration",
          tree: [
              { url: "relnotes/relnotes.htm", title: "Entire Net-Work Administration 6.5 Release Information",
                tree: [
                    { url: "relnotes/platform.htm", title: "Supported Operating System Platforms" },
                    { url: "relnotes/enh.htm", title: "Enhancements" },
                    { url: "relnotes/tapeinfo.htm", title: "Installation Media Information" },
                    { url: "relnotes/req.htm", title: "Requirements and Restrictions" },
                    { url: "relnotes/eom.htm", title: "End of Maintenance" },
                    { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
                ]
              },
              { url: "concepts/conover.htm", title: "Entire Net-Work Concepts",
                tree: [
                    { url: "concepts/intro.htm", title: "Introduction to Entire Net-Work" },
                    { url: "concepts/design.htm", title: "Designing Your Entire Net-Work Configuration" },
                    { url: "concepts/lic.htm", title: "Licensing Entire Net-Work" },
                    { url: "concepts/start.htm", title: "Starting Entire Net-Work" },
                    { url: "concepts/wcp_sec_zos.htm", title: "Entire Net-Work Security (z/OS only)" },
                ]
              },
              { url: "install/instover.htm", title: "Entire Net-Work Installation",
                tree: [
                    { url: "install/sysreq.htm", title: "System Requirements" },
                    { url: "install/geninfo.htm", title: "Installation Overview" },
                    { url: "install/os390.htm", title: "z/OS Environments" },
                    { url: "install/zap.htm", title: "Zap Naming Convention" },
                ]
              },
              { url: "admin/adover.htm", title: "Entire Net-Work Administration",
                tree: [
                    { url: "admin/convent.htm", title: "Conventions" },
                    { url: "admin/tcpipov.htm", title: "TCP/IP Overview" },
                    { url: "admin/wtc_hist.htm", title: "History of TCP/IP" },
                    { url: "admin/wtc_prot.htm", title: "TCP/IP Protocol Stack" },
                    { url: "admin/wtc_prov.htm", title: "Supported TCP/IP Transport Providers" },
                    { url: "admin/IPv4IPv6.htm", title: "Connection Handling in Mixed IPv4/IPv6 Environments" },
                    { url: "admin/wtc_api.htm", title: "TCP/IP API Modules" },
                    { url: "admin/wtc_prob.htm", title: "Problem Determination" },
                    { url: "admin/tcpxov.htm", title: "Simple Connection Line Driver Overview" },
                    { url: "admin/tcpxhow.htm", title: "How the Entire Net-Work Simple Connection Line Driver Operates" },
                    { url: "admin/tcpxreq.htm", title: "Simple Connection Line Driver Prerequisites" },
                    { url: "admin/wtci_os.htm", title: "Installing the Simple Connection Line Driver Under z/OS" },
                    { url: "admin/wtci_bs2.htm", title: "Installing the Simple Connection Line Driver Under BS2000" },
                    { url: "admin/tcpxcon.htm", title: "Connecting to Entire Net-Work 7" },
                    { url: "admin/tcpxdrv.htm", title: "TCPX DRIVER Statement" },
                    { url: "admin/tcpxlink.htm", title: "TCPX LINK Statement" },
                    { url: "admin/tcpxcmds.htm", title: "Simple Connection Line Driver Operator Commands" },
                    { url: "admin/tcpxmod.htm", title: "Model Links" },
                    { url: "admin/tcpxstat.htm", title: "Simple Connection Line Driver Statistics" },
                    { url: "admin/uescon.htm", title: "Connecting to UES-Enabled Adabas Databases" },
                    { url: "admin/amn.htm", title: "Adabas Manager" },
                    { url: "admin/stgest.htm", title: "Estimating Entire Net-Work Storage Requirements" },
                ]
              },
              { url: "adi/adi.htm", title: "Adabas Directory Server Administration",
                tree: [
                    { url: "adi/concepts.htm", title: "Adabas Directory Server Concepts" },
                    { url: "adi/relnotes.htm", title: "Release Notes" },
                    { url: "adi/installation.htm", title: "Installing and Uninstalling Adabas Directory Server on Linux, UNIX and Windows" },
                    { url: "adi/installation_zos.htm", title: "Installing and Running Adabas Directory Server on z/OS" },
                    { url: "adi/switch_c_java.htm", title: "Switching between C and Java Implementations of the Directory Server on Linux, UNIX and Windows Platforms." },
                    { url: "adi/wcposmh.htm", title: "About the Adabas Manager" },
                    { url: "adi/adiadmin.htm", title: "Performing Adabas Directory Server Administration" },
                    { url: "adi/adiamnt.htm", title: "Maintaining Directory Server Links" },
                    { url: "adi/adiapart.htm", title: "Maintaining Partitions" },
                    { url: "adi/adiatarg.htm", title: "Maintaining Targets" },
                    { url: "adi/adiahost.htm", title: "Changing Hosts" },
                    { url: "adi/advconf.htm", title: "Advanced Directory Server Configuration" },
                    { url: "adi/advsupt.htm", title: "Advanced Support Operations" },
                    { url: "adi/wcpoport.htm", title: "Port Number Reference" },
                ]
              },
              { url: "approg/apover.htm", title: "Application Programmer's Reference",
                tree: [
                    { url: "approg/progcom.htm", title: "Programmable Command Interface" },
                ]
              },
              { url: "ref/refover.htm", title: "Statement and Command Reference",
                tree: [
                    { url: "ref/wcprconv.htm", title: "Conventions" },
                    { url: "ref/adarun.htm", title: "ADARUN Parameters" },
                    { url: "ref/parmstat.htm", title: "Entire Net-Work Parameter Statements" },
                    { url: "ref/opcoms.htm", title: "Entire Net-Work Operator Commands" },
                ]
              },
              { url: "messages/messover.htm", title: "Entire Net-Work Messages and Codes",
                tree: [
                    { url: "messages/conv.htm", title: "Conventions" },
                    { url: "messages/formats.htm", title: "Entire Net-Work Message Formats" },
                    { url: "messages/nucresp.htm", title: "Adabas Response Codes" },
                    { url: "messages/snasense.htm", title: "SNA Sense Codes" },
                    { url: "messages/APSPSX.htm", title: "APSPSX* - ADAECS or ADATCP Messages" },
                    { url: "messages/MLC.htm", title: "Software AG Licensing Messages" },
                    { url: "messages/NET.htm", title: "NETnnnn - Entire Net-Work Control Module Messages" },
                    { url: "messages/NETB.htm", title: "NETB* - Entire Net-Work Expandable Buffer Pool Messages" },
                    { url: "messages/NETE.htm", title: "NETE* - zEnterprise Data Compression (zEDC) Support Messages" },
                    { url: "messages/ADAIOR.htm", title: "NETInn - ADAIOR Messages" },
                    { url: "messages/NETM.htm", title: "NETM* - ADAMPM Messages" },
                    { url: "messages/NETL.htm", title: "NETL* -- Licensing Messages" },
                    { url: "messages/NETP.htm", title: "NETP* - Simple Connection Line Driver Messages" },
                    { url: "messages/NETT.htm", title: "NETT* - Translation Routine Messages" },
                    { url: "messages/NETU.htm", title: "NETU* - Batch Utility Program Messages" },
                    { url: "messages/tsmsgs.htm", title: "XTS* - Software AG Internal Transport Subsystem Messages" },
                    { url: "messages/abends.htm", title: "User Abend Codes" },
                ]
              },
              { url: "general/glossary.htm", title: "Glossary" },
              { url: "license/license.htm", title: "Software AG Mainframe Product Licensing" },
              { url: "wcl/wcl.htm", title: "Entire Net-Work Client Installation and Administration",
                tree: [
                    { url: "wcl/conv.htm", title: "Conventions" },
                    { url: "wcl/wclov.htm", title: "Concepts" },
                    { url: "wcl/wcpopart.htm", title: "Understanding Partitioning" },
                    { url: "wcl/wcpofilt.htm", title: "Understanding Filtering" },
                    { url: "wcl/relnotes.htm", title: "Release Notes" },
                    { url: "wcl/installwcl.htm", title: "Installing and Uninstalling Entire Net-Work Client" },
                    { url: "wcl/wcli_svc.htm", title: "Starting and Stopping Entire Net-Work Client" },
                    { url: "wcl/wcla_ov.htm", title: "Entire Net-Work Client Administration" },
                    { url: "wcl/wcposhrl.htm", title: "Directing Log Files to a Shared Server" },
                    { url: "wcl/wcpoport.htm", title: "Port Number Reference" },
                    { url: "wcl/wcpconfig.htm", title: "Entire Net-Work Configuration Parameters" },
                    { url: "wcl/adiutil.htm", title: "Entire Net-Work Utility Functions for the Directory Server (checkadi and setadi)" },
                ]
              },
          ]
  },
  ]
};

var mainProject = 0;

$.event.trigger({ type: "fishidbloaded", db: entirenetworkadministration });

==> arf-4.2.1-en-download.zip: arf-4.2.1-en/webhelp/arf-webhelp/wca/navig/contents_wca.js <==
//
//	FindinSite-CD-JS-HelpIndex database entirenetworkadministration
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entirenetworkadministration = {
    baseurls: ["../"],
    varname: "entirenetworkadministration",
    tree: [
        { url: "overview.htm", title: "Entire Net-Work Administration",
          tree: [
              { url: "relnotes/relnotes.htm", title: "Entire Net-Work Administration 6.5 Release Information",
                tree: [
                    { url: "relnotes/platform.htm", title: "Supported Operating System Platforms" },
                    { url: "relnotes/enh.htm", title: "Enhancements" },
                    { url: "relnotes/tapeinfo.htm", title: "Installation Media Information" },
                    { url: "relnotes/req.htm", title: "Requirements and Restrictions" },
                    { url: "relnotes/eom.htm", title: "End of Maintenance" },
                    { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
                ]
              },
              { url: "concepts/conover.htm", title: "Entire Net-Work Concepts",
                tree: [
                    { url: "concepts/intro.htm", title: "Introduction to Entire Net-Work" },
                    { url: "concepts/design.htm", title: "Designing Your Entire Net-Work Configuration" },
                    { url: "concepts/lic.htm", title: "Licensing Entire Net-Work" },
                    { url: "concepts/start.htm", title: "Starting Entire Net-Work" },
                    { url: "concepts/wcp_sec_zos.htm", title: "Entire Net-Work Security (z/OS only)" },
                ]
              },
              { url: "install/instover.htm", title: "Entire Net-Work Installation",
                tree: [
                    { url: "install/sysreq.htm", title: "System Requirements" },
                    { url: "install/geninfo.htm", title: "Installation Overview" },
                    { url: "install/os390.htm", title: "z/OS Environments" },
                    { url: "install/zap.htm", title: "Zap Naming Convention" },
                ]
              },
              { url: "admin/adover.htm", title: "Entire Net-Work Administration",
                tree: [
                    { url: "admin/convent.htm", title: "Conventions" },
                    { url: "admin/tcpipov.htm", title: "TCP/IP Overview" },
                    { url: "admin/wtc_hist.htm", title: "History of TCP/IP" },
                    { url: "admin/wtc_prot.htm", title: "TCP/IP Protocol Stack" },
                    { url: "admin/wtc_prov.htm", title: "IBM TCP/IP Communication Subsystem and API" },
                    { url: "admin/IPv4IPv6.htm", title: "Connection Handling in Mixed IPv4/IPv6 Environments" },
                    { url: "admin/wtc_api.htm", title: "TCP/IP API Modules" },
                    { url: "admin/wtc_prob.htm", title: "Problem Determination" },
                    { url: "admin/tcpxov.htm", title: "Simple Connection Line Driver Overview" },
                    { url: "admin/tcpxhow.htm", title: "How the Entire Net-Work Simple Connection Line Driver Operates" },
                    { url: "admin/tcpxreq.htm", title: "Simple Connection Line Driver Prerequisites" },
                    { url: "admin/wtci_os.htm", title: "Installing the Simple Connection Line Driver Under z/OS" },
                    { url: "admin/wtci_bs2.htm", title: "Installing the Simple Connection Line Driver Under BS2000" },
                    { url: "admin/tcpxcon.htm", title: "Connecting to Entire Net-Work 7" },
                    { url: "admin/tcpxdrv.htm", title: "TCPX DRIVER Statement" },
                    { url: "admin/tcpxlink.htm", title: "TCPX LINK Statement" },
                    { url: "admin/tcpxcmds.htm", title: "Simple Connection Line Driver Operator Commands" },
                    { url: "admin/tcpxmod.htm", title: "Model Links" },
                    { url: "admin/tcpxstat.htm", title: "Simple Connection Line Driver Statistics" },
                    { url: "admin/uescon.htm", title: "Connecting to UES-Enabled Adabas Databases" },
                    { url: "admin/amn.htm", title: "Adabas Manager" },
                    { url: "admin/stgest.htm", title: "Estimating Entire Net-Work Storage Requirements" },
                ]
              },
              { url: "adi/adi.htm", title: "Adabas Directory Server Administration",
                tree: [
                    { url: "adi/concepts.htm", title: "Adabas Directory Server Concepts" },
                    { url: "adi/relnotes.htm", title: "Release Notes" },
                    { url: "adi/installation.htm", title: "Installing and Uninstalling Adabas Directory Server on Linux, UNIX and Windows" },
                    { url: "adi/installation_zos.htm", title: "Installing and Running Adabas Directory Server on z/OS" },
                    { url: "adi/switch_c_java.htm", title: "Switching between C and Java Implementations of the Directory Server on Linux, UNIX and Windows Platforms." },
                    { url: "adi/wcposmh.htm", title: "About the Adabas Manager" },
                    { url: "adi/adiadmin.htm", title: "Performing Adabas Directory Server Administration" },
                    { url: "adi/adiamnt.htm", title: "Maintaining Directory Server Links" },
                    { url: "adi/adiapart.htm", title: "Maintaining Partitions" },
                    { url: "adi/adiatarg.htm", title: "Maintaining Targets" },
                    { url: "adi/adiahost.htm", title: "Changing Hosts" },
                    { url: "adi/advconf.htm", title: "Advanced Directory Server Configuration" },
                    { url: "adi/advsupt.htm", title: "Advanced Support Operations" },
                    { url: "adi/wcpoport.htm", title: "Port Number Reference" },
                ]
              },
              { url: "approg/apover.htm", title: "Application Programmer's Reference",
                tree: [
                    { url: "approg/progcom.htm", title: "Programmable Command Interface" },
                ]
              },
              { url: "ref/refover.htm", title: "Statement and Command Reference",
                tree: [
                    { url: "ref/wcprconv.htm", title: "Conventions" },
                    { url: "ref/adarun.htm", title: "ADARUN Parameters" },
                    { url: "ref/parmstat.htm", title: "Entire Net-Work Parameter Statements" },
                    { url: "ref/opcoms.htm", title: "Entire Net-Work Operator Commands" },
                ]
              },
              { url: "messages/messover.htm", title: "Entire Net-Work Messages and Codes",
                tree: [
                    { url: "messages/conv.htm", title: "Conventions" },
                    { url: "messages/formats.htm", title: "Entire Net-Work Message Formats" },
                    { url: "messages/nucresp.htm", title: "Adabas Response Codes" },
                    { url: "messages/snasense.htm", title: "SNA Sense Codes" },
                    { url: "messages/MLC.htm", title: "Software AG Licensing Messages" },
                    { url: "messages/NET.htm", title: "NETnnnn - Entire Net-Work Control Module Messages" },
                    { url: "messages/NETB.htm", title: "NETB* - Entire Net-Work Expandable Buffer Pool Messages" },
                    { url: "messages/NETE.htm", title: "NETE* - zEnterprise Data Compression (zEDC) Support Messages" },
                    { url: "messages/ADAIOR.htm", title: "NETInn - ADAIOR Messages" },
                    { url: "messages/NETM.htm", title: "NETM* - ADAMPM Messages" },
                    { url: "messages/NETP.htm", title: "NETP* - Simple Connection Line Driver Messages" },
                    { url: "messages/NETT.htm", title: "NETT* - Translation Routine Messages" },
                    { url: "messages/NETU.htm", title: "NETU* - Batch Utility Program Messages" },
                    { url: "messages/tsmsgs.htm", title: "XTS* - Software AG Internal Transport Subsystem Messages" },
                    { url: "messages/abends.htm", title: "User Abend Codes" },
                ]
              },
              { url: "general/glossary.htm", title: "Glossary" },
              { url: "license/license.htm", title: "Software AG Mainframe Product Licensing" },
              { url: "wcl/wcl.htm", title: "Entire Net-Work Client Installation and Administration",
                tree: [
                    { url: "wcl/conv.htm", title: "Conventions" },
                    { url: "wcl/wclov.htm", title: "Concepts" },
                    { url: "wcl/wcpopart.htm", title: "Understanding Partitioning" },
                    { url: "wcl/wcpofilt.htm", title: "Understanding Filtering" },
                    { url: "wcl/relnotes.htm", title: "Release Notes" },
                    { url: "wcl/installwcl.htm", title: "Installing and Uninstalling Entire Net-Work Client" },
                    { url: "wcl/wcli_svc.htm", title: "Starting and Stopping Entire Net-Work Client" },
                    { url: "wcl/wcla_ov.htm", title: "Entire Net-Work Client Administration" },
                    { url: "wcl/wcposhrl.htm", title: "Directing Log Files to a Shared Server" },
                    { url: "wcl/wcpoport.htm", title: "Port Number Reference" },
                    { url: "wcl/wcpconfig.htm", title: "Entire Net-Work Configuration Parameters" },
                    { url: "wcl/adiutil.htm", title: "Entire Net-Work Utility Functions for the Directory Server (checkadi and setadi)" },
                ]
              },
          ]
  },
  ]
};

var mainProject = 0;

$.event.trigger({ type: "fishidbloaded", db: entirenetworkadministration });
